@@ -5,13 +5,13 @@ my $explanation = q<
 	bundled with the distribution.
 >;
 
-use 5.008003;
-use base qw[Module::Package::Dist];
+use 5.005;
 use strict;
 
 BEGIN {
 	$Module::Package::Dist::RDF::AUTHORITY = 'cpan:TOBYINK';
-	$Module::Package::Dist::RDF::VERSION   = '0.006';
+	$Module::Package::Dist::RDF::VERSION   = '0.007';
+	@Module::Package::Dist::RDF::ISA       = 'Module::Package::Dist';
 }
 
 sub _main
@@ -23,11 +23,11 @@ sub _main
 
 {
 	package Module::Package::Dist::RDF::standard;
-	use 5.008003;
+	use 5.005;
 	use strict;
 	BEGIN {
 		$Module::Package::Dist::RDF::standard::AUTHORITY = 'cpan:TOBYINK';
-		$Module::Package::Dist::RDF::standard::VERSION   = '0.006';
+		$Module::Package::Dist::RDF::standard::VERSION   = '0.007';
 		@Module::Package::Dist::RDF::standard::ISA       = 'Module::Package::Dist::RDF';
 	}
 }
